@@ -14,6 +14,7 @@ def clear_state_on_replication_change(stream, state):
     last_replication_method = singer.get_bookmark(state, tap_stream_id, 'last_replication_method')
     if last_replication_method is not None and (current_replication_method != last_replication_method):
         log_msg = 'Replication method changed from %s to %s, will re-replicate entire table %s'
+        LOGGER.info(log_msg, last_replication_method, current_replication_method, tap_stream_id)
         state = singer.reset_stream(state, tap_stream_id)
 
     state = singer.write_bookmark(state, tap_stream_id, 'last_replication_method', current_replication_method)
@@ -28,15 +29,15 @@ def sync_stream(config, state, stream):
     replication_method = metadata.get(md_map, (), 'replication-method')
     key_properties = metadata.get(md_map, (), 'table-key-properties')
 
-    rmSet = {'LOG_BASED'}
+    rmSet = {'FULL_TABLE', 'LOG_BASED'}
     if replication_method not in rmSet:
         LOGGER.info('Unknown replication method: %s ', replication_method)
         replication_method = 'LOG_BASED'
-        LOGGER.info('version 10 Setting default replication method: %s ', replication_method)
+        LOGGER.info('Setting default replication method: %s ', replication_method)
 
-    # Update replication method if it is not equal to prev replication method
+
+    # write state message with currently_syncing bookmark
     state = clear_state_on_replication_change(stream, state)
-    
     state = singer.set_currently_syncing(state, table_name)
     singer.write_state(state)
 
@@ -52,20 +53,25 @@ def sync_stream(config, state, stream):
     elif replication_method == 'LOG_BASED':
         LOGGER.info("Syncing log based for stream: %s", table_name)
 
+
+        if not singer.get_bookmark(state, table_name, 'initial_full_table_complete'):
+            msg = 'Must complete full table sync before replicating from dynamodb streams for %s'
+            LOGGER.info(msg, table_name)
+
+            state = log_based.get_initial_bookmarks(config, state, table_name)
+            singer.write_state(state)
+
+            rows_saved += full_table.sync(config, state, stream)
+
         if log_based.has_stream_aged_out(state, table_name):
-            LOGGER.info("Clearing state because stream has aged out")
+            LOGGER.info("Clearing state because stream has aged out : %s",singer.get_bookmark(state, table_name, 'initial_full_table_complete'))
             state.get('bookmarks', {}).pop(table_name)
+            # as full table already done
+            state = singer.write_bookmark(state,
+                                    table_name,
+                                    'initial_full_table_complete',
+                                    True)
 
-        # if not singer.get_bookmark(state, table_name, 'initial_full_table_complete'):
-        #     msg = 'Must complete full table sync before replicating from dynamodb streams for %s'
-        #     LOGGER.info(msg, table_name)
-
-        #     state = log_based.get_initial_bookmarks(config, state, table_name)
-        #     singer.write_state(state)
-
-        #     rows_saved += full_table.sync(config, state, stream)
-
-#without any full row count just runing log based sync on empty state
         rows_saved += log_based.sync(config, state, stream)
     else:
         LOGGER.info('Unknown replication method: %s for stream: %s', replication_method, table_name)
