@@ -80,15 +80,10 @@ def get_shard_records(streams_client, stream_arn, shard, sequence_number):
 
 def sync_shard(shard, seq_number_bookmarks, streams_client, stream_arn, projection, deserializer, table_name, stream_version, state):
     seq_number = seq_number_bookmarks.get(shard['ShardId'])
-    
+
     rows_synced = 0
 
     for record in get_shard_records(streams_client, stream_arn, shard, seq_number):
-        LOGGER.info("Record got here  : %s",record)
-        LOGGER.info("type of record seq number: %s,%s",type(seq_number),type(record['dynamodb']['SequenceNumber']))
-        # if record['dynamodb']['SequenceNumber']<=seq_number :
-        #     LOGGER.info("Skipping sync of shard %s as no records updated",shard['ShardId'])
-        #     continue
         if record['eventName'] == 'REMOVE':
             record_message = deserializer.deserialize_item(record['dynamodb']['Keys'])
             record_message[SDC_DELETED_AT] = singer.utils.strftime(record['dynamodb']['ApproximateCreationDateTime'])
@@ -110,9 +105,10 @@ def sync_shard(shard, seq_number_bookmarks, streams_client, stream_arn, projecti
         singer.write_message(record_message)
 
         rows_synced += 1
-        seq_number_bookmarks[shard['ShardId']]=record['dynamodb']['SequenceNumber']
 
+        seq_number_bookmarks[shard['ShardId']] = record['dynamodb']['SequenceNumber']
         state = singer.write_bookmark(state, table_name, 'shard_seq_numbers', seq_number_bookmarks)
+
         # Every 100 rows write the state
         if rows_synced % 100 == 0:
             singer.write_state(state)
@@ -196,6 +192,7 @@ def sync(config, state, stream):
     finished_shard_bookmarks = singer.get_bookmark(state, table_name, 'finished_shards')
     if not finished_shard_bookmarks:
         finished_shard_bookmarks = []
+
     # The list of shardIds we found this sync. Is used to determine which
     # finished_shard_bookmarks to kill
     found_shards = []
@@ -206,17 +203,21 @@ def sync(config, state, stream):
 
     for shard in get_shards(streams_client, stream_arn):
         found_shards.append(shard['ShardId'])
-        # Only sync shards which we have not fully synced already 
-        rows_synced += sync_shard(shard, seq_number_bookmarks,
-                                    streams_client, stream_arn, projection, deserializer,
-                                    table_name, stream_version, state)
+        # Only sync shards which we have not fully synced already
+        if shard['ShardId'] not in finished_shard_bookmarks:
+            rows_synced += sync_shard(shard, seq_number_bookmarks,
+                                      streams_client, stream_arn, projection, deserializer,
+                                      table_name, stream_version, state)
+
         # Now that we have fully synced the shard, move it from the
         # shard_seq_numbers to finished_shards.
         finished_shard_bookmarks.append(shard['ShardId'])
         state = singer.write_bookmark(state, table_name, 'finished_shards', finished_shard_bookmarks)
-        LOGGER.info("got seq_number_bookmarks after sync shard : %s", seq_number_bookmarks)
+
         if seq_number_bookmarks.get(shard['ShardId']):
+            seq_number_bookmarks.pop(shard['ShardId'])
             state = singer.write_bookmark(state, table_name, 'shard_seq_numbers', seq_number_bookmarks)
+
         singer.write_state(state)
 
     for shardId in finished_shard_bookmarks:
@@ -226,6 +227,7 @@ def sync(config, state, stream):
             state = singer.write_bookmark(state, table_name, 'finished_shards', finished_shard_bookmarks)
 
     singer.write_state(state)
+
     return rows_synced
 
 
@@ -252,7 +254,7 @@ def has_stream_aged_out(state, table_name):
 
     # If it has been > than 19h30m since the last successful sync of this
     # stream then we consider the stream to be aged out
-    return time_span > datetime.timedelta(hours=19, minutes=30)
+    return time_span > datetime.timedelta(hours=0, minutes=30)
 
 # Backoff for both ReadTimeout and ConnectTimeout error for 5 times
 @backoff.on_exception(backoff.expo,
